Hermaphrodite Coelomocyte System
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

COELOMOCYTE SYSTEM Click pictures for new window with figure and legend, click again for high resolution image
1 General Information The adult C. elegans hermaphrodite has six coelomocytes: large, ovoid, mesodermal cells situated as three pairs (right, left and dorsal) in the pseudocoelomic cavity adjacent to the somatic musculature (CcFIG 1). Four coelomocytes are present at hatching and two are generated in the first larval stage. Because there is evidence for absorption and concentration of soluble materials by coelomocytes of various nematode species, these cells were suggested to be phagocytic and similar in function to the macrophages of vertebrates (Chitwood and Chitwood, 1950). In larger nematode species, such as Ascaris suum, the coelomocytes can indeed phagocytose invading organisms (Bolla et al., 1972). Their inclusions and vesicles stain easily with dyes such as Methylene blue, Neutral red and Neutral violet, and these dyes sometimes appear to collect in high concentrations. Similarly, because of their ability to continuously endocytose and accumulate a variety of macromolecules from the body cavity fluid, coelomocytes of C. elegans have been suggested to serve immune, scavenging and hepatic functions (Fares and Grant, 2002; Yanowitz and Fire, 2005). Unlike macrophages of higher organisms, however, coelomocytes of C. elegans do not seem to be capable of phagocytosis (Ewbank, 2002). Also, they are not actively migratory and their position in the body cavity is relatively fixed, possibly by attachments to the body wall. As a result, coelomocytes rely on both the movements of the animal and the body cavity fluid for accessing foreign material. Like the intestine and gonad, coelomocyte positioning reveals dextral handedness of the animal grown at 20°C; the ventral anterior pair is located on the right side and close to the pharynx, and the ventral posterior pair is on the left side and anterior to the vulva. When animals are cultivated at 10°C, this handedness may become reversed such that 0.5% of animals shows sinistral handedness instead of dextral (Wood et al., 1996). Of the dorsal pair of coelomocytes, one cell is located on the right side and one is located on the left. CcFIG 1: Coelomocytes in the adult hermaphrodite. Three pairs of coelomocytes reside in the pseudocoelomic cavity. Four of these cells are on the ventral side. Two of these (ccPR and ccAR) are situated close to the head, whereas the other two (ccPL and ccAL) are close to midbody, anterior to vulva. The remaining pair (ccDR and ccDL) is located dorsally in the posterior body. An epifluorescent image of a transgenic animal expressing the reporter gene unc-122::GFP in coelomocytes is overlayed on the DIC image of the whole animal, seen from the right side. (Inset, left) A magnified DIC image, right lateral view, of ccDR (arrow) between intestine (In), distal gonad (DG), and body wall (Bw). The nucleus contains a nucleolus (white arrow). Arrowhead points to a vesicle within the cell. (Inset, right) Magnified epifluorescent image of the same cell; the vesicle is seen as translucent. (N) Nucleus. (Strain source: D. Williams and E. Jorgensen.) 2 Embryonic Development The coelomocytes arise from embryonic MS (mesodermal blast) and postembryonic M lineages (CcFIG 2). The right ventral (ventral anterior; ccAR and ccPR) and the left ventral (ventral posterior; ccAL and ccPL) pairs are derived from MS granddaughters MSpp and MSap, respectively (CcFIG 2 and CcFIG 3). They are generated from symmetrical divisions late in embryogenesis, when most of the other embryonic cell divisions have been completed (Sulston et al., 1983). Although the mother cell for each pair is born during the large burst of embryonic cell divisions, they remain arrested for a couple of hours before final cell division and differentiation. During this arrest in cell division before the elongation of the embryo, the two mother cells migrate posteriorly from the head where there are born, giving rise to the specific localizations of their daughter pairs of coelomocytes (CcFIG 2) (Hedgecock et al., 1987). CcFIG 2: Coelomocyte lineage. A. The right ventral and the left ventral coelomocyte pairs are derived from symmetrical divisions of MS granddaughters MSpp and MSap, respectively, during embryogenesis. Although the precursors for each pair are born during the burst of embryonic cell divisions, they delay their final divisions until most of the other embryonic cell divisions are completed. B. The dorsal pair is derived from the post-embryonic M lineage at the late-L1 stage and they differentiate into coelomocytes during early L2. C. Migration of the coelomocyte mother cells and M blast cell during embryogenesis between 250-400 minutes after first cleavage. The M cell is born on the left side, migrates posteriorly and toward the midline, and eventually migrates to the right side of the animal. The right and left coelomocyte mother cells are born next to the pharynx and then migrate posteriorly. All migrations are completed before the elongation of the embryo. CcFIG 3: Two pairs of coelomocytes are generated in the embryo. A. The embryonic coelomocytes at approximately 470 minutes after fertilization at 20°C, as seen from the left side. The left- (ccAL and ccPL) and right-side (ccAR and ccPR) coelomocytes are born from symmetric divisions after their mothers migrate posteriorly. The non-motile sister (MSapapap) of the left coelomocyte mother cell, which becomes a body wall muscle, is marked with an asterisk. (Thin gray lines) Borders of the pharynx (Ph), intestine (In), and gonad primordium (GP). (Based on Sulston et al., 1983.) B. DIC (left), epifluorescent (middle) and DIC/epifluorescent (right) micrographs of a 1.5-fold embryo expressing the reporter gene, unc-122::GFP in the right coelomocyte pair. Asterisks label the nuclei of coelomocytes. C. The same embryo as in B shown at the left-side level of the animal. The left side coelomocyte pair (ccAL and ccPL) is seen. D. Epifluorescent images of coelomocytes in 1.5-fold (top), three-fold (middle), and adult (bottom) animals expressing unc-122::GFP. The size of the coelomocytes and the sizes of their endocytic vesicles (arrowheads) increase as the animal grows. Magnification, 600x. (Strain source: D. Williams and E. Jorgensen.) The MS lineage also gives rise to the M mesoblast, which is responsible for all nongonadal mesoderm formation during post-embryonic development, including the two dorsal coelomocytes (ccDR and ccDL). The M mesoblast is born on the left side of the embryo next to the pharynx and then migrates to the posterior of the animal, following a ventral path between the two germ-line progenitors Z2 and Z3. It lingers on the midline for some time, but eventually moves to the right-hand side of the intestine and attaches to the body wall over QV5 (CcFIG 2 and CcFIG 4) (Sulston et al., 1983). Here, several consecutive divisions give rise to 18 cells by the L1 molt. Of these cells, 14 become body wall (striated) muscles, 2 become sex (nonstriated) muscle progenitor cells, and 2 dorsal cells (Mdlpa and Mdrpa) differentiate into coelomocytes during the L2 stage. In males, the M lineage gives rise to a single dorsal coelomocyte so that the total number of coelomocytes in males is five instead of six. Also in L1 males, one of the ventral left-side coelomocytes is located posterior to the gonad primordium rather than anteriorly, as in L1 hermaphrodite (see Introduction to Male Anatomy - Anatomical differences between sexes; Sulston and Horvitz, 1977). CcFIG 4: Coelomocytes in early L1. Embryonically generated coelomocytes are localized at stereotyped positions on the right and left ventral sides. A. The early L1 nuclei as seen from the left side. The ventral left pair is located slightly anterior to the gonad primordium (GP). The ventral right coelomocyte pair (faint yellow) and M blast cell (faint green) nuclei are also shown, although they reside on the right side of the animal. (Bwmu) Body wall muscle; (Exc) excretory cell. The body wall muscle cells and the ventral cord motor neurons (purple ovals) are more numerous than shown here. B. Epifluorescent micrograph of an early-L1 stage, unc-122::GFP transgenic animal. (V) Vesicles (insets); (GP) gonad primordium. C. DIC/Epifluorescent (left) and epifluorescent (right) micrographs of ccAR and ccPR in an L1 animal. Nuclei (N) are granulated and do not contain nucleoli in the L1 stage. (V) Vesicle. Magnification 400x. (Strain source: D. Williams and E. Jorgensen). 3 Structure and Function While coelomocytes in C. elegans are ovoid in shape, they can adopt stellate shapes in some other species. Each coelomocyte is about 10-15 μm in diameter and its cytoplasm contains a distended rough endoplasmic reticulum and many membrane-bound vesicles of various sizes (CcFIG 5) (Fares and Greenwald, 2001). When viewed by DIC optics, the cells are distinctive in that they contain both pale vacuoles and highly refractile inclusions (Sulston and Horvitz, 1977). Each cell is covered by its own basal lamina. Some portions of the plasma membrane show active endocytosis, with multiple, approximately 0.1 μm endocytic invaginations lying in close proximity to one another (CcFIG 5). Foreign substances such as India ink, rhodamine-dextran, GFP, fluorescein isothiocyanate (FITC)-BSA and FITC-lipopolysaccharide of S. typhimurium, that are injected into the body cavity of C. elegans are rapidly taken up by coelomocytes (Fares and Greenwald, 2001, Zhang, et al., 2001). Although they do not normally take up yolk particles from the pseudocoelom, coelomocytes can be induced to take up GFP-tagged yolk particles, apparently due to the presence of the GFP moiety (Paupard et al., 2001). CcFIG 5: Electron micrograph of coelomocytes. A. Transmission electron micrograph (TEM) of ventral right coelomocytes in an adult animal. The cells are located in the pseudocoelomic space between the body wall muscle, intestine and gonad. Foreign substances in the body cavity reach the cc’s by the movement of the pseudocoelomic fluid during animal’s locomotion and are endocytosed by these cells. Coelomocytes do not take up yolk particles from pseudocoelom that are made by the intestine; yolk particles are endocytosed by the neighboring gonad instead. Bar, 1 μm. (Image source: [Hall] N533-negative N543. B. TEM of an individual coelomocyte. Multiple invaginations of plasma membrane are seen in regions where active endocytosis is taking place. Material is transported from these early endosomes to either the recycling endosomes, to be redirected to the cell surface, or late compartment endosomes and lysosomes, to be degraded. These compartments are seen as various sized vesicles within the cell (Fares and Grant, 2002; Treusch et al., 2004). The coelomocyte is surrounded by its basal lamina. Bar, 1 μm. (Image source: [Hall] negative F777.) Consistent with their role in uptake, several proteins known to function in endocytosis in other organisms are active in C. elegans coelomocytes (Fares and Greenwald, 2001). The fluid-phase markers that are taken up by coelomocytes travel through the endocytic (early and late) compartments and eventually reach lysosomes where they are degraded or stored if they are not amenable to digestion (Fares and Grant, 2002; Treusch et al., 2004). This active endocytosis by coelomocytes may function for scavenging as a primitive immune surveillance function. This function does not seem to be significant or essential for the animal's survival or fertility, however, because animals tolerate changes in the number of coelomocytes. Also, when coelomocytes are toxin-ablated, the treated animals continue to grow and bear progeny (Harfe et al., 1998; Fares and Greenwald, 2001; Yanowitz and Fire, 2005). Additionally, C. elegans seems to be susceptible to the intrapseudocoelomic injection of even small amounts of bacteria, which normally do not gain access to pseudocoelom due to three barriers: The grinder of the pharynx breaks down bacteria entering from the mouth; the multilayered cuticle envelops the body, acting a physical barrier; and a complex innate immune system that, at least in part, resembles that of higher organisms may function as a defense against bacterial infection (Millet and Ewbank 2004; Nicholas and Hodgkin 2004).
4 List of Coelomocytes ccAL ccAR ccDL ccDR ccPL ccPR 5 References Bolla, R.I, Weinstein, P.P. and Cain, G.D. 1972. Fine structure of the coelomocyte of adult Ascaris suum. J. Parasitol. 58: 1025-1036. Abstract Chitwood, B.G. and Chitwood, M.B. 1950. Somatic musculature, connective tissue, body cavity, and organs of body cavity. In An introduction to nematology. Chapter 4. pp 48-56. Baltimore, University Park Press. Ewbank J.J. 2002. Tackling both sides of the host-pathogen equation with Caenorhabditis elegans. Microbes Infect. 4: 247–256. Abstract Fares, H. and Grant, B. 2002. Deciphering endocytosis in Caenorhabditis elegans. Traffic 3:11-19. Article Fares, H. and Greenwald, I. 2001. Genetic analysis of endocytosis in Caenorhabditis elegans : coelomocyte uptake defective mutants. Genetics 159:133-145. Article Harfe, B.D., Gomes, A.V., Kenyon, C., Liu, J., Krause, M. and Fire, A. 1998. Analysis of a Caenorhabditis elegans Twist homolog identifies conserved and divergent aspects of mesodermal patterning. Genes Dev. 12: 2623-2635. Article Hedgecock, E.M., Culotti, J.G., Hall, D.H. and Stern, B.D. 1987. Genetics of cell and axon migrations in Caenorhabditis elegans. Development 100: 365-382. Article Millet A.C.M. and Ewbank J.J. 2004. Immunity in Caenorhabditis elegans. Curr. Opin. Immunol. 16: 4-9. Abstract Nicholas H. R. and Hodgkin J. 2004. Responses to infection and possible recognition strategies in the innate immune system of Caenorhabditis elegans. Mol. Immunol. 41: 479–493. Abstract Paupard, M.C., Miller, A., Grant, B., Hirsh, D. and Hall, D. 2001. Immuno-EM localization of GFP-tagged yolk proteins in C. elegans using microwave fixation. J. Histochem. Cytochem. 49: 949-956. Article Sulston, J. E. and Horvitz, H. R. 1977. Post-embryonic cell lineages of the nematode Caenorhabditis elegans. Dev. Biol. 56: 110-156. Article Sulston, J.E., Schierenberg, E., White, J.G. and Thomson, J.N. 1983. The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev. Biol. 100: 64-119. Article Treusch S., Knuth, S., Slaugenhaupt, S.A., Goldin, E., Grant, B.D. and Fares, H. 2004. Caenorhabditis elegans functional orthologue of human protein h-mucolipin-1 is required for lysosome biogenesis. Proc. Natl. Acad. Sci. 101: 4483-4488. Article Wood, W.B., Bergmann, D. and Florance, A. 1996. Maternal effect of low temperature on handedness determination in C. elegans embryos. Dev. Genet. 19: 222-230. Abstract Yanowitz, J. and Fire, A. 2005. Cyclin D involvement demarcates a late transition in C. elegans embryogenesis. Dev. Biol. 279: 244-251. Article Zhang, Y., Grant, B. and Hirsh, D. 2001. RME-8, a conserved J-domain protein, is required for endocytosis in Caenorhabditis elegans. Mol. Biol. Cell 12: 2011-2021. Article
This chapter should be cited as: Altun, Z.F. and Hall, D.H. 2009. Coelomocyte system. In WormAtlas. doi:10.3908/wormatlas.1.11 Edited for the web by Laura A. Herndon. Last revision: June 4, 2013.

©Copyright 2024 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |